@@ -40,7 +40,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <usb.h>
+#include <unistd.h>
 
 #include "ptp-pack.c"
 
